@@ -60,8 +60,11 @@ def qualify_tables(
                 table.set("catalog", catalog.copy())
 
     if (db or catalog) and not isinstance(expression, exp.Query):
+        with_ = expression.args.get("with") or exp.With()
+        cte_names = {cte.alias_or_name for cte in with_.expressions}
+
         for node in expression.walk(prune=lambda n: isinstance(n, exp.Query)):
-            if isinstance(node, exp.Table):
+            if isinstance(node, exp.Table) and node.name not in cte_names:
                 _qualify(node)
 
     for scope in traverse_scope(expression):
@@ -69,7 +72,8 @@ def qualify_tables(
             if isinstance(derived_table, exp.Subquery):
                 unnested = derived_table.unnest()
                 if isinstance(unnested, exp.Table):
-                    joins = unnested.args.pop("joins", None)
+                    joins = unnested.args.get("joins")
+                    unnested.set("joins", None)
                     derived_table.this.replace(exp.select("*").from_(unnested.copy(), copy=False))
                     derived_table.this.set("joins", joins)
 
@@ -100,9 +104,10 @@ def qualify_tables(
                 )
 
                 if pivots:
-                    if not pivots[0].alias:
-                        pivot_alias = next_alias_name()
-                        pivots[0].set("alias", exp.TableAlias(this=exp.to_identifier(pivot_alias)))
+                    pivot = pivots[0]
+                    if not pivot.alias:
+                        pivot_alias = source.alias if pivot.unpivot else next_alias_name()
+                        pivot.set("alias", exp.TableAlias(this=exp.to_identifier(pivot_alias)))
 
                     # This case corresponds to a pivoted CTE, we don't want to qualify that
                     if isinstance(scope.sources.get(source.alias_or_name), Scope):
