@@ -100,6 +100,10 @@ INT;
 LAST_DAY(tbl.timestamp_col);
 DATE;
 
+# dialect: snowflake
+NEXT_DAY(tbl.date_col, 'MONDAY');
+DATE;
+
 JUSTIFY_DAYS(INTERVAL '1' DAY);
 INTERVAL;
 
@@ -1543,6 +1547,14 @@ BIGINT;
 ABS(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+ADD_MONTHS(tbl.date_col, 2);
+DATE;
+
+# dialect: snowflake
+ADD_MONTHS(tbl.timestamp_col, -1);
+TIMESTAMP;
+
 # dialect: snowflake
 ASIN(tbl.double_col);
 DOUBLE;
@@ -1635,6 +1647,18 @@ INT;
 BIT_LENGTH(tbl.bin_col);
 INT;
 
+# dialect: snowflake
+BOOLNOT(tbl.int_col);
+BOOLEAN;
+
+# dialect: snowflake
+BOOLNOT(NULL);
+BOOLEAN;
+
+# dialect: snowflake
+BOOLXOR(2, 0);
+BOOLEAN;
+
 # dialect: snowflake
 CHARINDEX('world', 'hello world');
 INT;
@@ -1683,6 +1707,34 @@ BINARY;
 COMPRESS('Hello World', 'zlib(1)');
 BINARY;
 
+# dialect: snowflake
+DATE_PART('year', tbl.date_col);
+INT;
+
+# dialect: snowflake
+DATE_PART('month', tbl.timestamp_col);
+INT;
+
+# dialect: snowflake
+DATE_PART('day', tbl.date_col);
+INT;
+
+# dialect: snowflake
+DATEADD(HOUR, 3, TO_TIME('05:00:00'));
+TIME;
+
+# dialect: snowflake
+DATEADD(YEAR, 1, TO_TIMESTAMP('2022-05-08 14:30:00'));
+TIMESTAMP;
+
+# dialect: snowflake
+DATEADD(MONTH, 1, '2023-01-31'::DATE);
+DATE;
+
+# dialect: snowflake
+DATEADD(HOUR, 2, '2022-04-05'::DATE);
+TIMESTAMPNTZ;
+
 # dialect: snowflake
 DEGREES(PI()/3);
 DOUBLE;
@@ -1691,6 +1743,10 @@ DOUBLE;
 DEGREES(1);
 DOUBLE;
 
+# dialect: snowflake
+DATE_FROM_PARTS(1977, 8, 7);
+DATE;
+
 # dialect: snowflake
 DECOMPRESS_BINARY('compressed_data', 'SNAPPY');
 BINARY;
@@ -1787,6 +1843,50 @@ BOOLEAN;
 CONTAINS(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+CONVERT_TIMEZONE('America/New_York', '2024-08-06 09:10:00.000');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+CONVERT_TIMEZONE('America/Los_Angeles', 'America/New_York', '2024-08-06 09:10:00.000');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+DATEDIFF('year', tbl.date_col, tbl.date_col);
+INT;
+
+# dialect: snowflake
+DATEDIFF('month', tbl.timestamp_col, tbl.timestamp_col);
+INT;
+
+# dialect: snowflake
+TIMESTAMPDIFF('year', tbl.date_col, tbl.date_col);
+INT;
+
+# dialect: snowflake
+TIMESTAMPDIFF('month', tbl.timestamp_col, tbl.timestamp_col);
+INT;
+
+# dialect: snowflake
+TIMEDIFF('year', tbl.date_col, tbl.date_col);
+INT;
+
+# dialect: snowflake
+TIMEDIFF('month', tbl.timestamp_col, tbl.timestamp_col);
+INT;
+
+# dialect: snowflake
+DATE_TRUNC('year', TO_DATE('2024-05-09'));
+DATE;
+
+# dialect: snowflake
+DATE_TRUNC('minute', TO_TIME('08:50:48'));
+TIME;
+
+# dialect: snowflake
+DATE_TRUNC('minute', TO_TIMESTAMP('2024-05-09 08:50:57.891'));
+TIMESTAMP;
+
 # dialect: snowflake
 EDITDISTANCE('hello', 'world');
 INT;
@@ -1799,6 +1899,18 @@ INT;
 EDITDISTANCE('hello', 'world', 3);
 INT;
 
+# dialect: snowflake
+EXTRACT(YEAR, CAST('2024-05-09' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(MONTH FROM CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+INT;
+
+# dialect: snowflake
+EXTRACT(MINUTE, CAST('08:50:57' AS TIME));
+INT;
+
 # dialect: snowflake
 EXP(1);
 DOUBLE;
@@ -1859,6 +1971,10 @@ VARCHAR;
 HEX_ENCODE('Hello World', 'lower');
 VARCHAR;
 
+# dialect: snowflake
+HOUR(CAST('08:50:57' AS TIME));
+INT;
+
 # dialect: snowflake
 INITCAP('hello world');
 VARCHAR;
@@ -1903,6 +2019,18 @@ BINARY;
 LEFT(tbl.bin_col, NULL);
 BINARY;
 
+# dialect: snowflake
+LAST_DAY(CAST('2024-05-09' AS DATE));
+DATE;
+
+# dialect: snowflake
+LAST_DAY(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+DATE;
+
+# dialect: snowflake
+LAST_DAY(CAST('2024-02-15' AS DATE), MONTH);
+DATE;
+
 # dialect: snowflake
 LEN(tbl.str_col);
 INT;
@@ -1947,6 +2075,14 @@ INT;
 POSITION('abc', 'abcdef', 1);
 INT;
 
+# dialect: snowflake
+PREVIOUS_DAY(CAST('2024-05-09' AS DATE), 'MONDAY');
+DATE;
+
+# dialect: snowflake
+PREVIOUS_DAY(CAST('2024-05-09 08:50:57' AS TIMESTAMP), 'MONDAY');
+DATE;
+
 # dialect: snowflake
 PI();
 DOUBLE;
@@ -1955,6 +2091,14 @@ DOUBLE;
 POW(tbl.double_col, 2);
 DOUBLE;
 
+# dialect: snowflake
+RANDOM();
+BIGINT;
+
+# dialect: snowflake
+RANDOM(123);
+BIGINT;
+
 # dialect: snowflake
 RADIANS(tbl.double_col);
 DOUBLE;
@@ -1983,6 +2127,18 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+MINUTE(CAST('08:50:57' AS TIME));
+INT;
+
+# dialect: snowflake
+MONTHNAME(CAST('2024-05-09' AS DATE));
+VARCHAR;
+
+# dialect: snowflake
+MONTHNAME(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+VARCHAR;
+
 # dialect: snowflake
 MOD(tbl.bigint_col, 3);
 BIGINT;
@@ -1995,6 +2151,14 @@ DOUBLE;
 MOD(42, 7);
 INT;
 
+# dialect: snowflake
+MONTHS_BETWEEN(tbl.date_col, CAST('2019-01-01' AS DATE));
+DOUBLE;
+
+# dialect: snowflake
+MONTHS_BETWEEN(tbl.timestamp_col, CAST('2019-02-15 01:00:00' AS TIMESTAMP));
+DOUBLE;
+
 # dialect: snowflake
 'foo' REGEXP 'bar';
 BOOLEAN;
@@ -2171,6 +2335,10 @@ BIGINT;
 ROUND(tbl.double_col, 0, 'HALF_TO_EVEN');
 DOUBLE;
 
+# dialect: snowflake
+SECOND(CAST('08:50:57' AS TIME));
+INT;
+
 # dialect: snowflake
 SQUARE(tbl.double_col);
 DOUBLE;
@@ -2423,6 +2591,58 @@ STRING;
 TAN(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+TIMEADD(hour, 1, CAST('14:30:45' AS TIME));
+TIME;
+
+# dialect: snowflake
+TIMEADD(minute, 30, CAST('2024-05-09 14:30:45' AS TIMESTAMP));
+TIMESTAMP;
+
+# dialect: snowflake
+TIMEADD(day, 1, CAST('2024-05-09' AS DATE));
+DATE;
+
+# dialect: snowflake
+TIMEADD(hour, 1, CAST('2024-05-09' AS DATE));
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TIME_FROM_PARTS(14, 30, 45);
+TIME;
+
+# dialect: snowflake
+TIME_FROM_PARTS(14, 30, 45, 123);
+TIME;
+
+# dialect: snowflake
+TIMEFROMPARTS(14, 30, 45);
+TIME;
+
+# dialect: snowflake
+TIMEFROMPARTS(14, 30, 45, 123);
+TIME;
+
+# dialect: snowflake
+TIME_SLICE(tbl.timestamp_col, 15, 'minute');
+TIMESTAMP;
+
+# dialect: snowflake
+TIME_SLICE(tbl.date_col, 1, 'day', 'start');
+DATE;
+
+# dialect: snowflake
+TIMESTAMPADD(DAY, 5, CAST('2008-12-25' AS DATE));
+DATE;
+
+# dialect: snowflake
+TIMESTAMPADD(HOUR, 3, TO_TIME('05:00:00'));
+TIME;
+
+# dialect: snowflake
+TIMESTAMPADD(YEAR, 1, TO_TIMESTAMP('2022-05-08 14:30:00'));
+TIMESTAMP;
+
 # dialect: snowflake
 TRANSLATE('hello world', 'elo', 'XYZ');
 VARCHAR;
@@ -2431,6 +2651,10 @@ VARCHAR;
 UNICODE('€');
 INT;
 
+# dialect: snowflake
+WIDTH_BUCKET(tbl.double_col, 0, 100, 10);
+INT;
+
 # dialect: snowflake
 TRIM('hello world');
 VARCHAR;
