@@ -26,7 +26,15 @@ false;
 bool;
 
 null;
+UNKNOWN;
+
+# dialect: spark
 null;
+NULL;
+
+# dialect: databricks
+null;
+NULL;
 
 null and false;
 bool;
@@ -86,3 +94,9 @@ TIME;
 # dialect: bigquery
 EXTRACT(day from x);
 INT;
+
+CASE WHEN x THEN CAST(y AS DECIMAL(18, 2)) ELSE NULL END;
+DECIMAL(18,2);
+
+CASE WHEN x THEN NULL ELSE CAST(y AS DECIMAL(18, 2)) END;
+DECIMAL(18,2);
